@@ -38,7 +38,7 @@ def main():
 
     run_job_parser = subparsers.add_parser('run-job', help='run a job')
     run_job_parser.add_argument('project_id', default=False, help='project in which to run a job')
-    run_job_parser.add_argument('--tag', help='tag to include', action='append', nargs='*')
+    run_job_parser.add_argument('--tag', help='tag to include')
     run_job_parser.add_argument('--type', help='job type: annotation/composite')
 
     list_job_parser = subparsers.add_parser('list-jobs', help='list all jobs in a project')
